@@ -16,8 +16,17 @@ class ReferenceHashFileDB(HashFileDB):
         super().__init__(fs, path, **config)
         self._obj_cache: Dict["str", "HashFile"] = {}
 
+    def __hash__(self):
+        return hash((self.fs.protocol, self.path, *self._obj_cache.keys()))
+
+    def exists(self, oid: str) -> bool:
+        return oid in self._obj_cache
+
     def get(self, oid: str):
-        return self._obj_cache[oid]
+        try:
+            return self._obj_cache[oid]
+        except KeyError:
+            return super().get(oid)
 
     def add(
         self,
